.. _api:

API Reference
=============

Simple API
----------

.. module:: usort

.. autofunction:: usort_path
.. autoclass:: Result
.. autoclass:: SortWarning

Advanced API
------------

.. autofunction:: usort
.. autofunction:: usort_file
.. autofunction:: usort_stdin
.. autoclass:: Config
